@@ -13,4 +13,4 @@ if sys.version_info < (3, 7):
 
 del sys
 
-from fund_em import *
+from aifund.fund_sou.fund_em import *
